Class: MicrosoftKiotaFaraday::Middleware::ResponseHandlerOption
- Inherits:
-
Object
- Object
- MicrosoftKiotaFaraday::Middleware::ResponseHandlerOption
- Defined in:
- lib/microsoft_kiota_faraday/middleware/response_handler_option.rb
Constant Summary collapse
- RESPONSE_HANDLER_KEY =
'responseHandler'
Instance Attribute Summary collapse
-
#async_callback ⇒ Object
a lambda that takes the native response type and returns a Fiber with a MicrosoftKiotaAbstractions::Parsable.
Instance Method Summary collapse
Instance Attribute Details
#async_callback ⇒ Object
a lambda that takes the native response type and returns a Fiber with a MicrosoftKiotaAbstractions::Parsable
9 10 11 |
# File 'lib/microsoft_kiota_faraday/middleware/response_handler_option.rb', line 9 def async_callback @async_callback end |
Instance Method Details
#get_key ⇒ Object
11 12 13 |
# File 'lib/microsoft_kiota_faraday/middleware/response_handler_option.rb', line 11 def get_key RESPONSE_HANDLER_KEY end |